@@ -18,6 +18,18 @@
  * MA 02110-1301 USA
  */
 
+/**
+ * SECTION:xfce-dialogs
+ * @title: XfceDialogs
+ * @short_description: A collection of helper dialogs
+ * @stability: Stable
+ * @include: libxfce4ui/libxfce4ui.h
+ *
+ * Xfce-dialogs are a collection of helper dialogs to display
+ * the help dialog with link to the docs website, warning, info, and
+ * error dialogs and more.
+ **/
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -42,9 +54,6 @@
 #include <libxfce4ui/libxfce4ui-private.h>
 #include <libxfce4ui/libxfce4ui-alias.h>
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#include "libxfce4ui-dialog-ui.h"
-#endif
 
 static void
 xfce_dialog_show_help_auto_toggled (GtkWidget *button)
@@ -131,12 +140,12 @@ xfce_dialog_show_help_response (GtkWidget *dialog,
 
 /**
  * xfce_dialog_show_help:
- * @parent    : transient parent of the dialog, or %NULL.
- * @component : name of the component opening the help page or %NULL. If the
+ * @parent    : (allow-none): transient parent of the dialog, or %NULL.
+ * @component : (allow-none): name of the component opening the help page or %NULL. If the
  *              value is %NULL the target will be the main page of the
  *              documentation website.
- * @page      : subpage of the @component on the website or %NULL.
- * @offset    : anchor offset in @page or %NULL.
+ * @page      : (allow-none): subpage of the @component on the website or %NULL.
+ * @offset    : (allow-none): anchor offset in @page or %NULL.
  *
  * Asks the user to visit the online documentation. If confirmed, it will open
  * the webbrowser and redirect the user to the correct location.
@@ -161,13 +170,13 @@ xfce_dialog_show_help (GtkWindow   *parent,
 
 /**
  * xfce_dialog_show_help_with_version:
- * @parent    : transient parent of the dialog, or %NULL.
- * @component : name of the component opening the help page or %NULL. If the
+ * @parent    : (allow-none): transient parent of the dialog, or %NULL.
+ * @component : (allow-none): name of the component opening the help page or %NULL. If the
  *              value is %NULL the target will be the main page of the
  *              documentation website.
- * @page      : subpage of the @component on the website or %NULL.
- * @offset    : anchor offset in @page or %NULL.
- * @version   : alternative version, or %NULL to use xfce_version_string().
+ * @page      : (allow-none): subpage of the @component on the website or %NULL.
+ * @offset    : (allow-none): anchor offset in @page or %NULL.
+ * @version   : (allow-none): alternative version, or %NULL to use xfce_version_string().
  *
  * Asks the user to visit the online documentation. If confirmed, it will open
  * the webbrowser and redirect the user to the correct location.
@@ -312,8 +321,8 @@ xfce_dialog_show_help_with_version (GtkWindow   *parent,
 
 /**
  * xfce_dialog_show_info:
- * @parent         : transient parent of the dialog, or %NULL.
- * @secondary_text : secondary text of the dialog or %NULL.
+ * @parent         : (allow-none): transient parent of the dialog, or %NULL.
+ * @secondary_text : (allow-none): secondary text of the dialog or %NULL.
  * @primary_format : the printf()-style format for the primary problem description.
  * @...            : argument list for the @format.
  *
@@ -355,8 +364,8 @@ xfce_dialog_show_info (GtkWindow   *parent,
 
 /**
  * xfce_dialog_show_warning:
- * @parent         : transient parent of the dialog, or %NULL.
- * @secondary_text : secondary text of the dialog or %NULL.
+ * @parent         : (allow-none): transient parent of the dialog, or %NULL.
+ * @secondary_text : (allow-none): secondary text of the dialog or %NULL.
  * @primary_format : the printf()-style format for the primary problem description.
  * @...            : argument list for the @format.
  *
@@ -398,8 +407,8 @@ xfce_dialog_show_warning (GtkWindow   *parent,
 
 /**
  * xfce_dialog_show_error:
- * @parent         : transient parent of the dialog, or %NULL.
- * @error          : a #GError, which gives a more precise description of the problem or %NULL.
+ * @parent         : (allow-none): transient parent of the dialog, or %NULL.
+ * @error          : (allow-none): a #GError, which gives a more precise description of the problem or %NULL.
  * @primary_format : the printf()-style format for the primary problem description.
  * @...            : argument list for the @primary_format.
  *
@@ -442,12 +451,12 @@ xfce_dialog_show_error (GtkWindow    *parent,
 
 /**
  * xfce_dialog_confirm:
- * @parent         : transient parent of the dialog, or %NULL.
+ * @parent         : (allow-none): transient parent of the dialog, or %NULL.
  * @stock_id       : the stock name of the confirm button, for example #GTK_STOCK_YES or #GTK_STOCK_CLEAR.
- * @confirm_label  : if non-%NULL, this text is used on the confirm button together with the @stock_id icon.
- * @secondary_text : secondary text in the dialog.
- * @primary_format : the printf()-style format for the dialog question.
- * @...            : argument list for the @primary_format.
+ * @confirm_label  : (allow-none): if non-%NULL, this text is used on the confirm button together with the @stock_id icon.
+ * @secondary_text : (allow-none): secondary text in the dialog.
+ * @primary_format : (allow-none): the printf()-style format for the dialog question.
+ * @...            : (allow-none): argument list for the @primary_format.
  *
  * Runs a questions dialog, that has a 'Cancel' and a 'Confirm' button. The 'Confirm'
  * button text can be set by @action if given.
@@ -521,8 +530,8 @@ xfce_dialog_confirm (GtkWindow   *parent,
 
 /**
  * xfce_message_dialog_new_valist:
- * @parent            : transient parent of the dialog, or %NULL.
- * @title             : title of the dialog, or %NULL.
+ * @parent            : (allow-none): transient parent of the dialog, or %NULL.
+ * @title             : (allow-none): title of the dialog, or %NULL.
  * @icon_stock_id     : gtk stock icon name to show in the dialog.
  * @primary_text      : primary text shown in large bold font.
  * @secondary_text    : secondary text shown in normal font.
@@ -532,7 +541,7 @@ xfce_dialog_confirm (GtkWindow   *parent,
  * See xfce_message_dialog_new(), this version takes a va_list for
  * language bindings to use.
  *
- * Returns: A new #GtkMessageDialog.
+ * Returns: (transfer full): A new #GtkMessageDialog.
  **/
 GtkWidget *
 xfce_message_dialog_new_valist (GtkWindow   *parent,
@@ -545,7 +554,6 @@ xfce_message_dialog_new_valist (GtkWindow   *parent,
 {
 #if GTK_CHECK_VERSION (3, 0, 0)
   GtkBuilder  *gxml;
-  GError      *error = NULL;
   GtkWidget   *dialog;
   GtkWidget   *dialog_image;
   GtkWidget   *image;
@@ -561,17 +569,13 @@ xfce_message_dialog_new_valist (GtkWindow   *parent,
   g_return_val_if_fail (primary_text != NULL || secondary_text != NULL, NULL);
   g_return_val_if_fail (parent == NULL || GTK_IS_WINDOW (parent), NULL);
 
-  gxml = gtk_builder_new();
-  if (!gtk_builder_add_from_string (gxml, xfce4ui_dialog_ui, xfce4ui_dialog_ui_length, &error))
-    {
-      g_printerr ("Failed to parse UI description: %s\n", error->message);
-      g_clear_error (&error);
-      return NULL;
-    }
+
+  gxml = gtk_builder_new_from_resource ("/org/xfce/libxfce4ui/libxfce4ui-dialog-ui.ui");
 
   dialog = GTK_WIDGET(gtk_builder_get_object(gxml, "xfce4ui-dialog"));
   label_box = GTK_WIDGET(gtk_builder_get_object(gxml, "label-box"));
   dialog_image = GTK_WIDGET(gtk_builder_get_object(gxml, "icon_stock_id"));
+  gtk_window_set_default_size (GTK_WINDOW (dialog), 500, -1);
 
   if (parent)
     {
@@ -585,6 +589,9 @@ xfce_message_dialog_new_valist (GtkWindow   *parent,
       gchar *markedup_text = g_strdup_printf ("<span weight='bold' size='large'>%s</span>", primary_text);
 
       gtk_label_set_markup (GTK_LABEL (primary_label), markedup_text);
+      gtk_label_set_xalign (GTK_LABEL (primary_label), 0);
+      gtk_widget_set_vexpand (GTK_WIDGET (primary_label), TRUE);
+      gtk_widget_set_valign (GTK_WIDGET (primary_label), 1.0);
 
       gtk_container_add (GTK_CONTAINER (label_box), primary_label);
       gtk_widget_show (primary_label);
@@ -597,6 +604,9 @@ xfce_message_dialog_new_valist (GtkWindow   *parent,
       /* Add the secondary text, no special formatting done */
       GtkWidget *secondary_label = gtk_label_new (secondary_text);
       gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
+      gtk_label_set_xalign (GTK_LABEL (secondary_label), 0.0);
+      gtk_widget_set_vexpand (GTK_WIDGET (secondary_label), TRUE);
+      gtk_widget_set_valign (GTK_WIDGET (secondary_label), 0.0);
 
       gtk_container_add (GTK_CONTAINER (label_box), secondary_label);
       gtk_widget_show (secondary_label);
@@ -798,8 +808,8 @@ xfce_message_dialog_new_valist (GtkWindow   *parent,
 
 /**
  * xfce_message_dialog_new:
- * @parent            : transient parent of the dialog, or %NULL.
- * @title             : title of the dialog, or %NULL.
+ * @parent            : (allow-none): transient parent of the dialog, or %NULL.
+ * @title             : (allow-none): title of the dialog, or %NULL.
  * @stock_id          : gtk stock icon name to show in the dialog.
  * @primary_text      : primary text shown in large bold font.
  * @secondary_text    : secondary text shown in normal font.
@@ -868,7 +878,7 @@ xfce_message_dialog_new_valist (GtkWindow   *parent,
  * </programlisting>
  * </example>
  *
- * Return value: A new #GtkMessageDialog.
+ * Return value: (transfer full): A new #GtkMessageDialog.
  **/
 GtkWidget *
 xfce_message_dialog_new (GtkWindow   *parent,
@@ -896,8 +906,8 @@ xfce_message_dialog_new (GtkWindow   *parent,
 
 /**
  * xfce_message_dialog:
- * @parent            : transient parent of the dialog, or %NULL.
- * @title             : title of the dialog, or %NULL.
+ * @parent            : (allow-none): transient parent of the dialog, or %NULL.
+ * @title             : (allow-none): title of the dialog, or %NULL.
  * @stock_id          : gtk stock icon name to show in the dialog.
  * @primary_text      : primary text shown in large bold font.
  * @secondary_text    : secondary text shown in normal font.
